@@ -1,14 +1,25 @@
+# frozen_string_literal: true
+
 require 'puppetlabs_spec_helper/puppetlabs_spec_helper'
 
 # Don't want puppet getting the command line arguments for rake or autotest
 ARGV.clear
 
-# This is needed because we're using mocha with rspec instead of Test::Unit or MiniTest
-ENV['MOCHA_OPTIONS']='skip_integration'
-
 require 'puppet'
 require 'rspec/expectations'
-require 'mocha/api'
+
+# Detect whether the module is overriding the choice of mocking framework
+# @mock_framework is used since more than seven years, and we need to avoid
+# `mock_framework`'s autoloading to distinguish between the default, and
+# the module's choice.
+# See also below in RSpec.configure
+if RSpec.configuration.instance_variable_get(:@mock_framework).nil?
+  # This is needed because we're using mocha with rspec instead of Test::Unit or MiniTest
+  ENV['MOCHA_OPTIONS'] = 'skip_integration'
+
+  # Current versions of RSpec already load this for us, but who knows what's used out there?
+  require 'mocha/api'
+end
 
 require 'pathname'
 require 'tmpdir'
@@ -36,7 +47,7 @@ require 'puppetlabs_spec_helper/puppetlabs_spec/files'
 # to compatibility mode for older versions of puppet.
 begin
   require 'puppet/test/test_helper'
-rescue LoadError => err
+rescue LoadError => e
 end
 
 # This is just a utility class to allow us to isolate the various version-specific
@@ -49,7 +60,7 @@ module Puppet
     # Puppet's Settings singleton object, and other fun implementation details
     # that code external to puppet should really never know about.
     def self.initialize_via_fallback_compatibility(config)
-      $stderr.puts("Warning: you appear to be using an older version of puppet; spec_helper will use fallback compatibility mode.")
+      warn('Warning: you appear to be using an older version of puppet; spec_helper will use fallback compatibility mode.')
       config.before :all do
         # nothing to do for now
       end
@@ -70,11 +81,11 @@ module Puppet
 
         # Set the confdir and vardir to gibberish so that tests
         # have to be correctly mocked.
-        Puppet[:confdir] = "/dev/null"
-        Puppet[:vardir] = "/dev/null"
+        Puppet[:confdir] = '/dev/null'
+        Puppet[:vardir] = '/dev/null'
 
         # Avoid opening ports to the outside world
-        Puppet.settings[:bindaddress] = "127.0.0.1"
+        Puppet.settings[:bindaddress] = '127.0.0.1'
       end
 
       config.after :each do
@@ -82,7 +93,7 @@ module Puppet
 
         Puppet::Node::Environment.clear
         Puppet::Util::Storage.clear
-        Puppet::Util::ExecutionStub.reset if Puppet::Util.constants.include? "ExecutionStub"
+        Puppet::Util::ExecutionStub.reset if Puppet::Util.constants.include? 'ExecutionStub'
 
         PuppetlabsSpec::Files.cleanup
       end
@@ -91,7 +102,7 @@ module Puppet
 end
 
 # JJM Hack to make the stdlib tests run in Puppet 2.6 (See puppet commit cf183534)
-if not Puppet.constants.include? "Test" then
+unless Puppet.constants.include? 'Test'
   module Puppet::Test
     class LogCollector
       def initialize(logs)
@@ -104,7 +115,7 @@ if not Puppet.constants.include? "Test" then
     end
   end
   Puppet::Util::Log.newdesttype :log_collector do
-    match "Puppet::Test::LogCollector"
+    match 'Puppet::Test::LogCollector'
 
     def initialize(messages)
       @messages = messages
@@ -118,11 +129,17 @@ end
 
 # And here is where we do the main rspec configuration / setup.
 RSpec.configure do |config|
-  # Some modules depend on having mocha set up for them
-  config.mock_with :mocha
+  # Detect whether the module is overriding the choice of mocking framework
+  # @mock_framework is used since more than seven years, and we need to avoid
+  # `mock_framework`'s autoloading to distinguish between the default, and
+  # the module's choice.
+  if config.instance_variable_get(:@mock_framework).nil?
+    RSpec.warn_deprecation('puppetlabs_spec_helper: defaults `mock_with` to `:mocha`. See https://github.com/puppetlabs/puppetlabs_spec_helper#mock_with to choose a sensible value for you')
+    config.mock_with :mocha
+  end
 
   # determine whether we can use the new API or not, and call the appropriate initializer method.
-  if (defined?(Puppet::Test::TestHelper))
+  if defined?(Puppet::Test::TestHelper)
     # This case is handled by rspec-puppet since v1.0.0 (via 41257b33cb1f9ade4426b044f70be511b0c89112)
   else
     Puppet::PuppetSpecInitializer.initialize_via_fallback_compatibility(config)
@@ -158,5 +175,4 @@ RSpec.configure do |config|
     Puppet::Util::Log.close_all
     Puppet::Util::Log.level = @log_level
   end
-
 end
